==> haskell-chell-0.5-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chell
version:              0.5
visibility:           public
id:                   chell-0.5-JBhAXuXl3Yf2otvCr4KOlF
key:                  chell-0.5-JBhAXuXl3Yf2otvCr4KOlF
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.

    An example test suite, which verifies the behavior of artithmetic operators.

    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;

    import Test.Chell

    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]

    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)

    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))

    main :: IO ()
    main = defaultMain [tests_Math]
    @

    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @

category:             Testing
abi:                  48b927cded3fd775ea6fa3af857d1056
exposed:              True
exposed-modules:      Test.Chell
hidden-modules:       Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs:          /usr/lib/ghc-8.10.4/site-local/chell-0.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/chell-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/chell-0.5
hs-libraries:         HSchell-0.5-JBhAXuXl3Yf2otvCr4KOlF
depends:
    ansi-terminal-0.11-6nluG5txe6B9NiOiR32C01 base-4.14.1.0
    bytestring-0.10.12.0 options-1.2.1.1-10OQMC2raJ7BObisICl41L
    patience-0.3-2Ix6M9B0N5K9Yco78cuMj7
    random-1.2.0-5H7ZZJPy96IF0kgiy7zIEA template-haskell-2.16.0.0
    text-1.2.4.1 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html:         /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-0.5-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chell
version:              0.5
visibility:           public
id:                   chell-0.5-IFbQzsCBiyzAOaao1a7C1M
key:                  chell-0.5-IFbQzsCBiyzAOaao1a7C1M
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.

    An example test suite, which verifies the behavior of artithmetic operators.

    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;

    import Test.Chell

    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]

    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)

    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))

    main :: IO ()
    main = defaultMain [tests_Math]
    @

    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @

category:             Testing
abi:                  eea82db1f1b6555c5e5a8f1aede56c0c
exposed:              True
exposed-modules:      Test.Chell
hidden-modules:       Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs:          /usr/lib/ghc-8.10.4/site-local/chell-0.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/chell-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/chell-0.5
hs-libraries:         HSchell-0.5-IFbQzsCBiyzAOaao1a7C1M
depends:
    ansi-terminal-0.11-B33URfqMvdcAXWIdsUyVZE base-4.14.1.0
    bytestring-0.10.12.0 options-1.2.1.1-10OQMC2raJ7BObisICl41L
    patience-0.3-2Ix6M9B0N5K9Yco78cuMj7
    random-1.2.0-IgxPFWwCjnD1SXfjtysFzY template-haskell-2.16.0.0
    text-1.2.4.1 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html:         /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
